@@ -14,6 +14,7 @@ from plone.app.querystring import queryparser
 from collective.media.interfaces import ICanContainMedia
 from collective.portlet.relateditems.relateditems import Renderer as RelatedItemsRenderer
 from plone.portlet.collection.collection import Renderer as CollectionPortletRenderer
+from collective.portlet.manualRelated.manualrelatedportlet import Renderer as ManualRelatedPortletRenderer
 import re
 import time
 import json
@@ -613,6 +614,14 @@ class CollectionPortlet(CollectionPortletRenderer, CommonBrowserView):
     """
     _template = ViewPageTemplateFile('collection.pt')
     render = _template
+    
+class ManualRelatedPortlet(ManualRelatedPortletRenderer, CommonBrowserView):
+    """
+    Overriding the related Items
+    """
+    _template = ViewPageTemplateFile('collection.pt')
+    render = _template
+
 
 class FrontPageView(FolderListing):
     """
